==> healthrian_visualization_support-1.1.19.tar.gz: lib/src/widgets/cardio_click/ecg_heartbeat_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'package:auto_size_text/auto_size_text.dart';
import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'ecg_heartbeat_cardioclick.g.dart';

@CopyWith()
class EcgHeartbeatCardioClick extends StatelessWidget {
  const EcgHeartbeatCardioClick({
    super.key,
    this.style,
    this.fontSize = 50,
    this.width = 200,
    this.height = 50,this.isUsingMean = true,
  });

  final bool isUsingMean;
  final TextStyle? style;
  final double fontSize;
  final double width;
  final double height;

  @override
  Widget build(BuildContext context) {
    final previousValue = <int>[];
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder(
          stream: BLEManager().manageWearCardioT.streams.heartRateStreamEcg,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return const SizedBox();
            late final String displayValue;
            if (isUsingMean) {
              previousValue.add(snapshot.data ?? -1);
              if (previousValue.length > 10) previousValue.removeAt(0);

              final sorted = previousValue
                  .where((element) => element > 0)
                  .toList()
                ..sort((a, b) => a - b);
              if (sorted.isEmpty) {
                displayValue = ' - ';
              } else {
                final mid = sorted.length ~/ 2;
                displayValue = sorted[mid].toString();
              }
            } else {
              final value = snapshot.data ?? -1;
              if (value < 0) {
                displayValue = ' - ';
              } else {
                displayValue = value.toString();
              }
            }
            return SizedBox(
              width: width,
              height: height,
              child: AutoSizeText(
                displayValue,
                textAlign: TextAlign.center,
                overflow: TextOverflow.visible,
                style: style?.copyWith(fontSize: fontSize) ??
                    TextStyle(
                      fontSize: fontSize,
                      fontFamily: 'normal',
                    ),
                // style: style,
              ),
            );
          },
        );
      },
    );
  }
}

==> healthrian_visualization_support-1.1.20.tar.gz: lib/src/widgets/cardio_click/ecg_heartbeat_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'package:auto_size_text/auto_size_text.dart';
import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';

part 'ecg_heartbeat_cardioclick.g.dart';

@CopyWith()
class EcgHeartbeatCardioClick extends StatelessWidget {
  const EcgHeartbeatCardioClick({
    super.key,
    this.style,
    this.fontSize = 50,
    this.width = 200,
    this.height = 50,this.isUsingMean = true,
  });

  final bool isUsingMean;
  final TextStyle? style;
  final double fontSize;
  final double width;
  final double height;

  @override
  Widget build(BuildContext context) {
    final previousValue = <int>[];
    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder<int?>(
          stream: BLEManager().manageCardioClick.streams.heartRateStreamEcg,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return const SizedBox();
            late final String displayValue;
            if (isUsingMean) {
              previousValue.add(snapshot.data ?? -1);
              if (previousValue.length > 10) previousValue.removeAt(0);

              final sorted = previousValue
                  .where((element) => element > 0)
                  .toList()
                ..sort((a, b) => a - b);
              if (sorted.isEmpty) {
                displayValue = ' - ';
              } else {
                final mid = sorted.length ~/ 2;
                displayValue = sorted[mid].toString();
              }
            } else {
              final value = snapshot.data ?? -1;
              if (value < 0) {
                displayValue = ' - ';
              } else {
                displayValue = value.toString();
              }
            }
            return SizedBox(
              width: width,
              height: height,
              child: AutoSizeText(
                displayValue,
                textAlign: TextAlign.center,
                overflow: TextOverflow.visible,
                style: style?.copyWith(fontSize: fontSize) ??
                    TextStyle(
                      fontSize: fontSize,
                      fontFamily: 'normal',
                    ),
                // style: style,
              ),
            );
          },
        );
      },
    );
  }
}
